@@ -111,9 +111,10 @@ class Channel():
             async for message in subscriber:
 
                 data = TransData.fromBytes(message)
-                # print('got transdata[%d], type=%s' % (len(data.msg), data.type.name))
+                # print('🚚 Got transdata[%d], type=%s' % (len(data.msg), data.type.name))
 
                 if data.type in [ DataType.hello, DataType.connect, DataType.complete ]:
+                    print('🚚 Got Raw %s msg[%d]' % (data.type.name, len(data.msg)), data.msg)
                     # self.on_pending_msg(data.type, data.resolveMsg())
                     await self.event_queue.put((data.type, data.resolveMsg()))
                     if data.type == DataType.complete:
@@ -122,14 +123,14 @@ class Channel():
 
                 # file receiving
                 if data.type == DataType.file:
-                    # print('file data msg[%d]' % len(data.msg), data.msg)
+                    # print('🚚 Got File data[%d]' % len(data.msg))
                     self.receiving_file.pipe.send(data.msg)
                     # await sleep(1)
                     continue
 
                 # handle msg
                 msg: NormalMsg = data.resolveMsg(self.cipher)
-                # print('got Msg: %s' % msg.toPrettyString())
+                print('🚚 Got Encrypted msg: %s' % msg.toPrettyString())
 
                 if msg.type in [ MsgType.GetFile, MsgType.Reply, MsgType.Request, MsgType.Done, MsgType.Later, MsgType.Resume]:
                     # self.on_pending_msg(data.type, msg)
@@ -156,6 +157,7 @@ class Channel():
                     self.finish_file_write_process()
                     if self.receiving_file.format == file.FileFormat.TarArchived:
                         # untar
+                        print("untar...")
                         shutil.unpack_archive(self.receiving_file.path, self.receiving_file.uncompressed_dir, "tar")
                     await self.event_queue.put((data.type, msg))
         
@@ -191,7 +193,7 @@ class Channel():
         if datatype == DataType.complete:
             # should close
             complete: CompleteMsg = _msg
-            raise Exception("connection will close. reason: %s" % complete.reason)
+            raise Exception("connection will close. remote reason: %s" % complete.reason)
 
         if len(msgtypes) > 0:
 
@@ -215,12 +217,10 @@ class Channel():
     async def wait_on_sending_for(self, msgtypes: List[MsgType] = []) -> AsyncGenerator[Tuple[bytes, any], None]:
 
         msg: NormalMsg
-
         msgtypes_with_getfile = [MsgType.GetFile, MsgType.Later, MsgType.Done] + msgtypes
 
         print("wait_on_sending_for", msgtypes)
         while True:
-
             msg = await self.wait_for_msg(msgtypes=msgtypes_with_getfile)
             if msg.type in msgtypes:
                 break
@@ -237,9 +237,9 @@ class Channel():
             # handle request files: send a file/dir
             p = msg.params[0]
             if p not in self.session.files_provided or not os.path.exists(p):
-                print("warn: Failed to get a file not provided!!", p)
-                yield TransData.encrypted(NormalMsg(MsgType.SendFileEnd), self.cipher).toBytes()
-                continue
+                raise Exception("Failed to get a file not provided!! (%s)" % p)
+                # yield TransData.encrypted(NormalMsg(MsgType.SendFileEnd), self.cipher).toBytes(), None
+                # continue
             norm_path = os.path.abspath(p)
             async for e in file.file_generator(norm_path, self.session.dir, self.cipher):
                 yield e, None
@@ -247,6 +247,7 @@ class Channel():
         yield None, msg
 
 
+
     async def request_file(self, filename: str, received_files: List[str] = []) -> AsyncGenerator[bytes, None]:
 
         print('Try request file ', filename)
@@ -460,6 +461,7 @@ class Channel():
 
         if self.session.state == SessionState.ReplyTransferring:
             if self.session.role == SessionRole.Initiator:
+                print("handle reply:", reply.toPrettyString())
                 # 3. get files in reply
                 received_files = []
                 # receive all files into this session
@@ -467,8 +469,6 @@ class Channel():
                     async for e in self.request_file(filename, received_files):
                         yield e
 
-                print("got reply:", reply.toPrettyString())
-
                 # custom handle reply
                 if handle_reply:
                     # print('call custom handle reply')
@@ -484,7 +484,7 @@ class Channel():
                     if data:
                         yield data
 
-        print("👌Session Done!")
+        print("👌 Session Done!")
         self.session.state = SessionState.Done
 
 
